@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 var log4js = require('log4js'),
@@ -46,7 +47,7 @@ var express = require('express'),
 require('node-i18n-util')
 
 process.env.BABEL_ENV = 'server'
-require('babel-register')
+require('@babel/register')
 // Ignore required CSS in PatternFly components
 require('ignore-styles')
 
@@ -109,7 +110,7 @@ app.use(
     next()
   },
   createProxyMiddleware({
-    target: appConfig.get('hcmUiApiUrl') || 'https://localhost:4000/hcmuiapi',
+    target: appConfig.get('hcmUiApiUrl') || 'http://localhost:4000/hcmuiapi',
     changeOrigin: true,
     pathRewrite: {
       [`^${appConfig.get('contextPath')}/graphql`]: '/graphql'
@@ -141,64 +142,6 @@ app.use(
   })
 )
 
-app.use(
-  appConfig.get('headerContextPath'),
-  cookieParser(),
-  createProxyMiddleware({
-    target: appConfig.get('headerUrl'),
-    changeOrigin: true,
-    secure: false,
-    ws: true,
-    saveUninitialized: false
-  })
-)
-
-if (process.env.NODE_ENV === 'development') {
-  app.use(
-    appConfig.get('headerContextPath'),
-    cookieParser(),
-    (req, res, next) => {
-      res.setHeader('Cache-Control', 'no-store')
-      res.setHeader('Pragma', 'no-cache')
-      const accessToken = req.cookies['acm-access-token-cookie']
-      if (req.headers.authorization)
-        req.headers.authorization = `Bearer ${accessToken}`
-      else req.headers.Authorization = `Bearer ${accessToken}`
-      next()
-    },
-    createProxyMiddleware({
-      target: appConfig.get('headerUrl'),
-      changeOrigin: true,
-      secure: false,
-      ws: true
-    })
-  )
-
-  app.use(
-    `${appConfig.get('contextPath')}/api/proxy${appConfig.get(
-      'headerContextPath'
-    )}`,
-    cookieParser(),
-    (req, res, next) => {
-      res.setHeader('Cache-Control', 'no-store')
-      res.setHeader('Pragma', 'no-cache')
-      const accessToken = req.cookies['acm-access-token-cookie']
-      if (req.headers.authorization)
-        req.headers.authorization = `Bearer ${accessToken}`
-      else req.headers.Authorization = `Bearer ${accessToken}`
-      next()
-    },
-    createProxyMiddleware({
-      target: appConfig.get('headerUrl'),
-      changeOrigin: true,
-      pathRewrite: {
-        [`^${appConfig.get('contextPath')}/api/proxy`]: ''
-      },
-      secure: false
-    })
-  )
-}
-
 const hbs = exphbs.create({
   // Specify helpers which are only registered on this instance.
   helpers: {
@@ -268,31 +211,44 @@ app.get('/favicon.ico', (req, res) => res.sendStatus(204))
 app.locals.config = require('./lib/shared/config')
 app.locals.manifest = require('./public/webpack-assets.json')
 
-let server, privateKey, certificate, credentials
+let privateKey, certificate, credentials
+const http = require('http')
 const https = require('https')
 
 if (process.env.NODE_ENV === 'development') {
-  // use self-signed cert for local development
-  privateKey = fs.readFileSync('./sslcert/server.key', 'utf8')
-  certificate = fs.readFileSync('./sslcert/server.crt', 'utf8')
-  credentials = { key: privateKey, cert: certificate }
-  server = https.createServer(credentials, app)
+  try {
+    privateKey = fs.readFileSync(
+      process.env.serverKey || './sslcert/server.key',
+      'utf8'
+    )
+    certificate = fs.readFileSync(
+      process.env.serverCert || './sslcert/server.crt',
+      'utf8'
+    )
+    credentials = { key: privateKey, cert: certificate }
+  } catch (err) {
+    // in development mode; ignore and fall back to http
+  }
 } else {
   // NOTE: In production, SSL is provided by the ICP ingress.
   privateKey = fs.readFileSync('/certs/applicationui.key', 'utf8')
   certificate = fs.readFileSync('/certs/applicationui.crt', 'utf8')
   credentials = { key: privateKey, cert: certificate }
-  server = https.createServer(credentials, app)
 }
 
+const server = credentials
+  ? https.createServer(credentials, app)
+  : http.createServer(app)
+
 var port = process.env.PORT || appConfig.get('httpsPort')
+const url = `${
+  credentials ? 'https://' : 'http://'
+}localhost:${port}${CONTEXT_PATH}`
 
 // start server
 logger.info('Starting express server.')
 server.listen(port, () => {
-  logger.info(
-    `Application Lifecycle is now running on https://localhost:${port}${CONTEXT_PATH}`
-  )
+  logger.info(`Application Lifecycle is now running on ${url}`)
 })
 
 process.on('SIGTERM', () => {
