@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2021 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 module.exports.ACM_ACCESS_COOKIE = 'acm-access-token-cookie'
@@ -23,6 +24,8 @@ module.exports.OVERVIEW_REFRESH_INTERVAL_COOKIE =
 module.exports.DIAGRAM_REFRESH_INTERVAL_COOKIE =
   'mcm-diagram-interval-refresh-cookie'
 module.exports.REFRESH_TIMES = [15, 30, 60, 5 * 60, 30 * 60, 0]
+module.exports.DEFAULT_REFRESH_TIME = 15000
+module.exports.INITIAL_REFRESH_TIME = 15
 
 module.exports.OVERVIEW_QUERY_COOKIE = 'mcm-overview-query-cookie'
 module.exports.OVERVIEW_STATE_COOKIE = 'mcm-overview-state-cookie'
@@ -38,25 +41,33 @@ module.exports.RESOURCE_TYPES = {
   QUERY_APPLICATIONS: {
     name: 'QueryApplications',
     list: 'QueryApplicationList',
+    fallback: 'getApplications',
     kind: 'Application',
+    dataKey: 'applications',
     apiVersion: 'app.k8s.io/v1beta1'
   },
   QUERY_SUBSCRIPTIONS: {
     name: 'QuerySubscriptions',
     list: 'QuerySubscriptionList',
+    fallback: 'HCMSubscriptionList',
     kind: 'Subscription',
+    dataKey: 'subscriptions',
     apiVersion: module.exports.API_VERSION
   },
   QUERY_PLACEMENTRULES: {
     name: 'QueryPlacementRules',
     list: 'QueryPlacementRuleList',
+    fallback: 'HCMPlacementRuleList',
     kind: 'PlacementRule',
+    dataKey: 'placementRules',
     apiVersion: module.exports.API_VERSION
   },
   QUERY_CHANNELS: {
     name: 'QueryChannels',
     list: 'QueryChannelList',
+    fallback: 'HCMChannelList',
     kind: 'Channel',
+    dataKey: 'channels',
     apiVersion: module.exports.API_VERSION
   },
   HCM_APPLICATIONS: { name: 'HCMApplication', list: 'HCMApplicationList' },
@@ -74,21 +85,8 @@ module.exports.RESOURCE_TYPES = {
 module.exports.MCM_CLUSTERS_SERVICES_ACTIONS = {}
 
 module.exports.DOC_PATH_BASE =
-  'https://access.redhat.com/documentation/en-us/red_hat_advanced_cluster_management_for_kubernetes/2.2/html/manage_applications/managing-applications'
+  'https://access.redhat.com/documentation/en-us/red_hat_advanced_cluster_management_for_kubernetes/2.3/html/applications/managing-applications'
 
 module.exports.DOC_LINKS = {
-  HOME: `${module.exports.DOC_PATH_BASE}`,
-  TERMINOLOGY: `${
-    module.exports.DOC_PATH_BASE
-  }#application-model-and-definitions`,
-  APPLICATIONS: `${
-    module.exports.DOC_PATH_BASE
-  }#managing-application-resources`,
-  SUBSCRIPTIONS: `${
-    module.exports.DOC_PATH_BASE
-  }#creating-and-managing-subscriptions`,
-  PLACEMENT_RULES: `${
-    module.exports.DOC_PATH_BASE
-  }#creating-and-managing-placement-rules`,
-  CHANNELS: `${module.exports.DOC_PATH_BASE}#creating-and-managing-channels`
+  HOME: `${module.exports.DOC_PATH_BASE}`
 }
