@@ -1,9 +1,11 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
-
-export {default as ApplicationTopologyModule} from './ApplicationTopologyModule'
+// Copyright Contributors to the Open Cluster Management project
+export {
+  default as ApplicationTopologyModule
+} from './ApplicationTopologyModule'
