@@ -9,8 +9,6 @@ var equals = require('./equals');
  * Returns a new list without any consecutively repeating elements. `R.equals`
  * is used to determine equality.
  *
- * Dispatches to the `dropRepeats` method of the first argument, if present.
- *
  * Acts as a transducer if a transformer is given in list position.
  *
  * @func
@@ -25,4 +23,4 @@ var equals = require('./equals');
  *
  *     R.dropRepeats([1, 1, 1, 2, 3, 4, 4, 2, 2]); //=> [1, 2, 3, 4, 2]
  */
-module.exports = _curry1(_dispatchable('dropRepeats', _xdropRepeatsWith(equals), dropRepeatsWith(equals)));
+module.exports = _curry1(_dispatchable([], _xdropRepeatsWith(equals), dropRepeatsWith(equals)));
