@@ -1,4 +1,5 @@
 var _curry1 = require('./internal/_curry1');
+var _slice = require('./internal/_slice');
 var mean = require('./mean');
 
 
@@ -25,7 +26,7 @@ module.exports = _curry1(function median(list) {
   }
   var width = 2 - len % 2;
   var idx = (len - width) / 2;
-  return mean(Array.prototype.slice.call(list, 0).sort(function(a, b) {
+  return mean(_slice(list).sort(function(a, b) {
     return a < b ? -1 : a > b ? 1 : 0;
   }).slice(idx, idx + width));
 });
